@@ -9,8 +9,11 @@ import matplotlib.patches as mpatches
 from gwaslab.getsig import getsig
 from gwaslab.Log import Log
 from gwaslab.winnerscurse import wc_correct
+from gwaslab.winnerscurse import wc_correct_test
 import gc
+from statsmodels.stats.multitest import fdrcorrection
 
+from adjustText import adjust_text
 #20220422
 def compare_effect(path1,
                    cols_name_list_1, effect_cols_list_1,
@@ -22,17 +25,28 @@ def compare_effect(path1,
                    snplist=None,
                    mode="beta",
                    anno=False,
+                   anno_het=False,
+                   anno_min=0,
+                   anno_min1=0,
+                   anno_min2=0,
+                   anno_diff=0,
+                   scaled=False,
+                   scaled1=False,
+                   scaled2=False,
                    wc_correction=False, 
                    null_beta=0,
                    is_q=True,
+                   include_all=True,
                    q_level=0.05,
                    sig_level=5e-8,
+                   drop=False,
                    wc_sig_level=5e-8,
                    # reg
                    reg_box=dict(boxstyle='round', facecolor='white', alpha=1,edgecolor="grey"),
                    is_reg=True,
+                   fdr=False,
                    allele_match=False,
-                   r2_se=False,
+                   r_se=False,
                    is_45_helper_line=True,
                    legend_title=r'$ P < 5 x 10^{-8}$ in:',
                    legend_pos='upper left',
@@ -50,6 +64,9 @@ def compare_effect(path1,
     #[snpid,p,ea,nea]      ,[effect,se]
     #[snpid,p,ea,nea,chr,pos],[effect,se]
     #[snpid,p,ea,nea,chr,pos],[OR,OR_l,OR_h]
+    if scaled == True:
+        scaled1 = True
+        scaled2 = True
     
     if verbose: log.write("Start to process the raw sumstats for plotting...")
     
@@ -71,7 +88,8 @@ def compare_effect(path1,
     ######### 4 load sumstats1
     if verbose: log.write(" -Loading sumstats for "+label[0]+":",",".join(cols_to_extract))
     sumstats = pd.read_table(path1,sep=sep[0],usecols=cols_to_extract)
-    
+    if scaled1==True:
+        sumstats[cols_name_list_1[1]] = np.power(10,-sumstats[cols_name_list_1[1]])
     ######### 5 extract the common set
     common_snp_set = common_snp_set.intersection(sumstats[cols_name_list_1[0]].values)
     if verbose: log.write(" -Counting  variants available for both datasets:",len(common_snp_set)," variants...")
@@ -102,7 +120,8 @@ def compare_effect(path1,
         if verbose: log.write(" -Extract lead variants from "+label[0]+"...")
         sig_list_1 = getsig(sumstats,"SNPID","CHR","POS","P", verbose=verbose,sig_level=sig_level)
     
-    sig_list_1 = drop_duplicate_and_na(sig_list_1, sort_by="P", log=log ,verbose=verbose)
+    if drop==True:
+        sig_list_1 = drop_duplicate_and_na(sig_list_1, sort_by="P", log=log ,verbose=verbose)
 
     ######### 9 extract snplist2
     if snplist is not None:
@@ -112,7 +131,8 @@ def compare_effect(path1,
     
     if verbose: log.write(" -Loading sumstats for "+label[1]+":",",".join(cols_to_extract))
     sumstats = pd.read_table(path2,sep=sep[1],usecols=cols_to_extract)
-    
+    if scaled2==True:
+        sumstats[cols_name_list_2[1]] = np.power(10,-sumstats[cols_name_list_2[1]])
     ######### 10 rename sumstats2
     rename_dict = { cols_name_list_2[0]:"SNPID",
                     cols_name_list_2[1]:"P",
@@ -135,8 +155,8 @@ def compare_effect(path1,
         ######### 12.2 otherwise use the sutomatically detected lead SNPs
         sig_list_2 = getsig(sumstats,"SNPID","CHR","POS","P",
                                  verbose=verbose,sig_level=sig_level)
-
-    sig_list_2 = drop_duplicate_and_na(sig_list_2, sort_by="P", log=log ,verbose=verbose)
+    if drop==True:
+        sig_list_2 = drop_duplicate_and_na(sig_list_2, sort_by="P", log=log ,verbose=verbose)
 
     ######### 13 Merge two list using SNPID
     ##############################################################################
@@ -162,7 +182,8 @@ def compare_effect(path1,
     if len(eaf)>0: cols_to_extract.append(eaf[0])   
     if verbose: log.write(" -Extract statistics of selected variants from "+label[0]+" : ",",".join(cols_to_extract) )
     sumstats = pd.read_table(path1,sep=sep[0],usecols=cols_to_extract)
-
+    if scaled1==True:
+        sumstats[cols_name_list_1[1]] = np.power(10,-sumstats[cols_name_list_1[1]])
 
     if mode=="beta" or mode=="BETA" or mode=="Beta":
         rename_dict = { cols_name_list_1[0]:"SNPID",
@@ -188,7 +209,8 @@ def compare_effect(path1,
     sumstats.rename(columns=rename_dict, inplace=True)
     
     # drop na and duplicate
-    sumstats = drop_duplicate_and_na(sumstats,  sort_by="P_1", log=log , verbose=verbose)
+    if drop==True:
+        sumstats = drop_duplicate_and_na(sumstats,  sort_by="P_1", log=log , verbose=verbose)
     sumstats.drop("P_1",axis=1,inplace=True)
 
     if verbose: log.write(" -Merging "+label[0]+" effect information...")
@@ -209,6 +231,8 @@ def compare_effect(path1,
     
     if verbose: log.write(" -Extract statistics of selected variants from "+label[1]+" : ",",".join(cols_to_extract) )
     sumstats = pd.read_table(path2,sep=sep[1],usecols=cols_to_extract)
+    if scaled2==True:
+        sumstats[cols_name_list_2[1]] = np.power(10,-sumstats[cols_name_list_2[1]])
     gc.collect()
     if mode=="beta" or mode=="BETA" or mode=="Beta":
           rename_dict = { cols_name_list_2[0]:"SNPID",
@@ -230,7 +254,8 @@ def compare_effect(path1,
     if len(eaf)>0: rename_dict[eaf[1]]="EAF_2"
     sumstats.rename(columns=rename_dict, inplace=True)         
     # drop na and duplicate
-    sumstats = drop_duplicate_and_na(sumstats, sort_by="P_2", log=log, verbose=verbose)
+    if drop==True:
+        sumstats = drop_duplicate_and_na(sumstats, sort_by="P_2", log=log, verbose=verbose)
     sumstats.drop("P_2",axis=1,inplace=True)
 
     if verbose: log.write(" -Merging "+label[1]+" effect information...")
@@ -243,13 +268,16 @@ def compare_effect(path1,
     ################ 16 update sumstats1
     if verbose: log.write(" -Updating missing information for "+label[0]+" ...")
     sumstats = pd.read_table(path1,sep=sep[0],usecols=[cols_name_list_1[0],cols_name_list_1[1]])
+    if scaled1==True:
+        sumstats[cols_name_list_1[1]] = np.power(10,-sumstats[cols_name_list_1[1]])
     sumstats.rename(columns={
                         cols_name_list_1[0]:"SNPID",
                         cols_name_list_1[1]:"P_1"
                               },
                      inplace=True)
     # drop na and duplicate
-    sumstats = drop_duplicate_and_na(sumstats, sort_by="P_1", log=log, verbose=verbose)
+    if drop==True:
+        sumstats = drop_duplicate_and_na(sumstats, sort_by="P_1", log=log, verbose=verbose)
     
     sumstats.set_index("SNPID",inplace=True)
     sig_list_merged.update(sumstats)
@@ -257,17 +285,26 @@ def compare_effect(path1,
     ################# 17 update sumstats2
     if verbose: log.write(" -Updating missing information for "+label[1]+" ...")
     sumstats = pd.read_table(path2,sep=sep[1],usecols=[cols_name_list_2[0],cols_name_list_2[1]])
+    if scaled2==True:
+        sumstats[cols_name_list_2[1]] = np.power(10,-sumstats[cols_name_list_2[1]])
     sumstats.rename(columns={
                         cols_name_list_2[0]:"SNPID",
                         cols_name_list_2[1]:"P_2"
                               },
                      inplace=True)
     # drop na and duplicate
-    sumstats = drop_duplicate_and_na(sumstats, sort_by="P_2", log=log, verbose=verbose)              
+    if drop==True:
+        sumstats = drop_duplicate_and_na(sumstats, sort_by="P_2", log=log, verbose=verbose)              
     
     sumstats.set_index("SNPID",inplace=True)
     sig_list_merged.update(sumstats)
 
+    if scaled1 ==True :
+        if verbose:log.write(" -Sumstats -log10(P) values are being converted to P...")
+        sig_list_merged["P_1"] = np.power(10,-sig_list_merged["P_1"])
+    if scaled2 ==True :
+        if verbose:log.write(" -Sumstats -log10(P) values are being converted to P...")
+        sig_list_merged["P_2"] = np.power(10,-sig_list_merged["P_2"])
     ####
 #################################################################################
     ############## 18 init indicator
@@ -331,14 +368,45 @@ def compare_effect(path1,
             sig_list_merged = sig_list_merged.loc[sig_list_merged["EA_1"] == sig_list_merged["EA_2_aligned"]]
         else:
             if verbose: log.write(" -No variants with EA not matching...")
+    if fdr==True:
+        if verbose: log.write(" -Using FDR...")
+        sig_list_merged["P_1"] = fdrcorrection(sig_list_merged["P_1"])[1]
+        sig_list_merged["P_2"] = fdrcorrection(sig_list_merged["P_2"])[1]
+
     ####################################################################################################################################
     ## winner's curse correction using aligned beta
-    if wc_correction == True:
-        if verbose: log.write(" -Correcting BETA for winner's curse with threshold at {}...".format(sig_level))
+    if wc_correction == "all":
+        if verbose: log.write(" -Correcting BETA for winner's curse with threshold at {} for all variants...".format(sig_level))
         sig_list_merged["EFFECT_1_RAW"] = sig_list_merged["EFFECT_1"].copy()
         sig_list_merged["EFFECT_2_aligned_RAW"] = sig_list_merged["EFFECT_2_aligned"].copy()
+        
+        if verbose: log.write("  -Correcting BETA for {} variants in sumstats1...".format(sum(~sig_list_merged["EFFECT_1"].isna())))
         sig_list_merged["EFFECT_1"] = sig_list_merged[["EFFECT_1_RAW","SE_1"]].apply(lambda x: wc_correct(x[0],x[1],sig_level),axis=1)
+
+        if verbose: log.write("  -Correcting BETA for {} variants in sumstats2...".format(sum(~sig_list_merged["EFFECT_2_aligned"].isna())))
         sig_list_merged["EFFECT_2_aligned"] = sig_list_merged[["EFFECT_2_aligned_RAW","SE_2"]].apply(lambda x: wc_correct(x[0],x[1],sig_level),axis=1)
+    
+    elif wc_correction == "sig" :
+        if verbose: log.write(" - Correcting BETA for winner's curse with threshold at {} for significant variants...".format(sig_level))
+        sig_list_merged["EFFECT_1_RAW"] = sig_list_merged["EFFECT_1"].copy()
+        sig_list_merged["EFFECT_2_aligned_RAW"] = sig_list_merged["EFFECT_2_aligned"].copy()
+        if verbose: log.write("  -Correcting BETA for {} variants in sumstats1...".format(sum(sig_list_merged["P_1"]<sig_level)))
+        sig_list_merged.loc[sig_list_merged["P_1"]<sig_level, "EFFECT_1"]         = sig_list_merged.loc[sig_list_merged["P_1"]<sig_level, ["EFFECT_1_RAW","SE_1"]].apply(lambda x: wc_correct_test(x[0],x[1],sig_level),axis=1)
+        if verbose: log.write("  -Correcting BETA for {} variants in sumstats2...".format(sum(sig_list_merged["P_2"]<sig_level)))
+        sig_list_merged.loc[sig_list_merged["P_2"]<sig_level, "EFFECT_2_aligned"] = sig_list_merged.loc[sig_list_merged["P_2"]<sig_level, ["EFFECT_2_aligned_RAW","SE_2"]].apply(lambda x: wc_correct_test(x[0],x[1],sig_level),axis=1)
+    
+    elif wc_correction == "sumstats1" :
+        if verbose: log.write(" - Correcting BETA for winner's curse with threshold at {} for significant variants in sumstats1...".format(sig_level))
+        sig_list_merged["EFFECT_1_RAW"] = sig_list_merged["EFFECT_1"].copy()
+        if verbose: log.write("  -Correcting BETA for {} variants in sumstats1...".format(sum(sig_list_merged["P_1"]<sig_level)))
+        sig_list_merged.loc[sig_list_merged["P_1"]<sig_level, "EFFECT_1"]         = sig_list_merged.loc[sig_list_merged["P_1"]<sig_level, ["EFFECT_1_RAW","SE_1"]].apply(lambda x: wc_correct_test(x[0],x[1],sig_level),axis=1)
+        
+    elif wc_correction == "sumstats2" :
+        if verbose: log.write(" - Correcting BETA for winner's curse with threshold at {} for significant variants in sumstats2...".format(sig_level))
+        sig_list_merged["EFFECT_2_aligned_RAW"] = sig_list_merged["EFFECT_2_aligned"].copy()
+        if verbose: log.write("  -Correcting BETA for {} variants in sumstats2...".format(sum(sig_list_merged["P_2"]<sig_level)))
+        sig_list_merged.loc[sig_list_merged["P_2"]<sig_level, "EFFECT_2_aligned"] = sig_list_merged.loc[sig_list_merged["P_2"]<sig_level, ["EFFECT_2_aligned_RAW","SE_2"]].apply(lambda x: wc_correct_test(x[0],x[1],sig_level),axis=1)
+
     ########################## Het test############################################################
     ## heterogeneity test
     if (is_q is True) and (mode=="beta" or mode=="BETA" or mode=="Beta"):
@@ -363,7 +431,11 @@ def compare_effect(path1,
         if verbose: log.write(" -Het rate:" ,len(sig_list_merged.loc[sig_list_merged["HetP"]<0.05,:])/len(sig_list_merged))   
     
     # extract group
-    sum0 = sig_list_merged.loc[sig_list_merged["indicator"]==0,:].dropna(axis=0)
+    if include_all==True:
+        sum0 = sig_list_merged.loc[sig_list_merged["indicator"]==0,:].dropna(axis=0)
+    else:
+        sum0 = pd.DataFrame()
+
     sum1only = sig_list_merged.loc[sig_list_merged["indicator"]==1,:].dropna(axis=0)
     sum2only = sig_list_merged.loc[sig_list_merged["indicator"]==2,:].dropna(axis=0)
     both     = sig_list_merged.loc[sig_list_merged["indicator"]==3,:].dropna(axis=0)
@@ -426,23 +498,42 @@ def compare_effect(path1,
     
     ## annotation #################################################################################################################
     if anno==True:
-        from adjustText import adjust_text
         sig_list_toanno = sig_list_merged.dropna(axis=0)
-        texts=[]
+        if anno_het == True:
+            sig_list_toanno = sig_list_toanno.loc[sig_list_toanno["Edge_color"]=="black",:]
+        
+
+        sig_list_toanno = sig_list_toanno.loc[sig_list_toanno["EFFECT_1"].abs() >=anno_min1 ,:]
+        sig_list_toanno = sig_list_toanno.loc[sig_list_toanno["EFFECT_2_aligned"].abs() >=anno_min2 ,:]
+        sig_list_toanno = sig_list_toanno.loc[(sig_list_toanno["EFFECT_1"].abs() >=anno_min) & (sig_list_toanno["EFFECT_2_aligned"].abs() >=anno_min) ,:]
+        sig_list_toanno = sig_list_toanno.loc[np.abs(sig_list_toanno["EFFECT_1"] - sig_list_toanno["EFFECT_2_aligned"]) >=anno_diff,:]
+
+        texts_l=[]
+        texts_r=[]
         for index, row in sig_list_toanno.iterrows():
             if mode=="beta" or mode=="BETA" or mode=="Beta":
-                texts.append(plt.text(row["EFFECT_1"], row["EFFECT_2_aligned"],index, ha='center', va='center')) 
+                if row["EFFECT_1"] <  row["EFFECT_2_aligned"]:
+                    texts_l.append(plt.text(row["EFFECT_1"], row["EFFECT_2_aligned"],index,ha="right",va="bottom"))
+                else:
+                    texts_r.append(plt.text(row["EFFECT_1"], row["EFFECT_2_aligned"],index,ha="left",va="top"))
             else:
                 texts.append(plt.text(row["OR_1"], row["OR_2_aligned"],index, ha='center', va='center')) 
-        adjust_text(texts, arrowprops=dict(arrowstyle='->', color='grey'))
+        adjust_text(texts_l,autoalign =False,precision =0.001,lim=1000, ha="right",va="bottom", expand_text=(1,1.8) , expand_objects=(0.1,0.1), expand_points=(1.8,1.8) ,force_objects=(0.8,0.8) ,arrowprops=dict(arrowstyle='-|>', color='grey'),ax=ax)
+        adjust_text(texts_r,autoalign =False,precision =0.001,lim=1000, ha="left",va="top", expand_text=(1,1.8) , expand_objects=(0.1,0.1), expand_points=(1.8,1.8) ,force_objects =(0.8,0.8),arrowprops=dict(arrowstyle='-|>', color='grey'),ax=ax)
     
     elif type(anno) is dict:
         # if input is a dict
         sig_list_toanno = sig_list_toanno.loc[sig_list_toanno.index.isin(list(anno.keys())),:]
+        if anno_het == True:
+            sig_list_toanno = sig_list_toanno.loc[sig_list_toanno["Edge_color"]=="black",:]
+        sig_list_toanno = sig_list_toanno.loc[sig_list_toanno["EFFECT_1"].abs() >=anno_min1 ,:]
+        sig_list_toanno = sig_list_toanno.loc[sig_list_toanno["EFFECT_2_aligned"].abs() >=anno_min2 ,:]
+        sig_list_toanno = sig_list_toanno.loc[(sig_list_toanno["EFFECT_1"].abs() >=anno_min) & (sig_list_toanno["EFFECT_2_aligned"].abs() >=anno_min) ,:]
+        
         texts=[]
         for index, row in sig_list_toanno.iterrows():
             texts.append(plt.text(row["EFFECT_1"], row["EFFECT_2_aligned"],anno[index], ha='right', va='top')) 
-        adjust_text(texts,ha='right', va='top',arrowprops=dict(arrowstyle='->', color='grey'))
+        adjust_text(texts, expand_text=(1.2,1.2) , expand_objects=(1.2,1.2), expand_points=(1.2,1.2) ,arrowprops=dict(arrowstyle='-|>', color='grey'),ax=ax)
     #################################################################################################################################
     
     # plot x=0,y=0, and a 45 degree line
@@ -469,24 +560,25 @@ def compare_effect(path1,
             reg = ss.linregress(sig_list_merged["EFFECT_1"],sig_list_merged["EFFECT_2_aligned"])
             
             # estimate se for r2
-            if r2_se==True:
-                if verbose:log.write(" -Estimating SE for Rsq using Jackknife method.")
-                r2_se_jackknife = jackknife_r2(sig_list_merged)
-                r2_se_jackknife_string = " ({:.2f})".format(r2_se_jackknife)
-            else:
-                r2_se_jackknife_string= ""
+            #if r_se==True:
+            #    if verbose:log.write(" -Estimating SE for Rsq using Jackknife method.")
+            #    r_se_jackknife = jackknife_r2(sig_list_merged)
+            #    r_se_jackknife_string = " ({:.2f})".format(r_se_jackknife)
+            #else:
+            r_se_jackknife_string= ""
         else:
             reg = ss.linregress(sig_list_merged["OR_1"],sig_list_merged["OR_2_aligned"])
         #### calculate p values based on selected value , default = 0 
         if verbose:log.write(" -Calculating p values based on given null slope :",null_beta)
         t_score = (reg[0]-null_beta) / reg[4]
         degree = len(sig_list_merged.dropna())-2
-        p = ss.t.sf(abs(t_score), df=degree)*2
+        p =  reg[3]
+        #ss.t.sf(abs(t_score), df=degree)*2
         if verbose:log.write(" -Beta_se = ", reg[4])
-        if verbose:log.write(" -H0 beta = ", null_beta, ", recalculated p = ", "{:.2e}".format(p))
+        #if verbose:log.write(" -H0 beta = ", null_beta, ", recalculated p = ", "{:.2e}".format(p))
         if verbose:log.write(" -H0 beta =  0",", default p = ", "{:.2e}".format(reg[3]))
-        if r2_se==True:
-            if verbose:log.write(" -R2 se (jackknife) = {:.2e}".format(r2_se_jackknife))
+        #if r_se==True:
+        #    if verbose:log.write(" -R se (jackknife) = {:.2e}".format(r_se_jackknife))
 
         if reg[0] > 0:
             #if regression coeeficient >0 : auxiliary line slope = 1
@@ -494,11 +586,15 @@ def compare_effect(path1,
                 ax.axline([min(xl,yl),min(xl,yl)], [max(xh, yh),max(xh, yh)],zorder=1,**helper_line_args)
 
             #add text
-            p12=str("{:.2e}".format(p)).split("e")[0]
-            pe =str(int("{:.2e}".format(p).split("e")[1]))
+            try:
+                p12=str("{:.2e}".format(p)).split("e")[0]
+                pe =str(int("{:.2e}".format(p).split("e")[1]))
+            except:
+                p12="0"
+                pe="0"
             p_text="$p = " + p12 + " \\times  10^{"+pe+"}$"
             p_latex= f'{p_text}'
-            ax.text(0.98,0.02,"$y =$ "+"{:.2f}".format(reg[1]) +" $+$ "+ "{:.2f}".format(reg[0])+" $x$, "+ p_latex + ", $r^{2} =$" +"{:.2f}".format(reg[2])+r2_se_jackknife_string, va="bottom",ha="right",transform=ax.transAxes, bbox=reg_box, **fontargs)
+            ax.text(0.98,0.02,"$y =$ "+"{:.2f}".format(reg[1]) +" $+$ "+ "{:.2f}".format(reg[0])+" $x$, "+ p_latex + ", $r =$" +"{:.2f}".format(reg[2])+r_se_jackknife_string, va="bottom",ha="right",transform=ax.transAxes, bbox=reg_box, **fontargs)
         else:
             #if regression coeeficient <0 : auxiliary line slope = -1
             if is_45_helper_line is True:
@@ -507,11 +603,15 @@ def compare_effect(path1,
                 else:
                     ax.axline([min(xl,yl),-min(xl,yl)], [max(xh, yh),-max(xh, yh)],zorder=1,**helper_line_args)
             #add text
-            p12=str("{:.2e}".format(p)).split("e")[0]
-            pe =str(int("{:.2e}".format(p).split("e")[1]))
+            try:
+                p12=str("{:.2e}".format(p)).split("e")[0]
+                pe =str(int("{:.2e}".format(p).split("e")[1]))
+            except:
+                p12="0"
+                pe="0"
             p_text="$p = " + p12 + " \\times  10^{"+pe+"}$"
             p_latex= f'{p_text}'
-            ax.text(0.98,0.02,"$y =$ "+"{:.2f}".format(reg[1]) +" $-$ "+ "{:.2f}".format(abs(reg[0]))+" $x$, "+ p_latex + ", $r^{2} =$" +"{:.2f}".format(reg[2])+r2_se_jackknife_string, va="bottom",ha="right",transform=ax.transAxes,bbox=reg_box,**fontargs)
+            ax.text(0.98,0.02,"$y =$ "+"{:.2f}".format(reg[1]) +" $-$ "+ "{:.2f}".format(abs(reg[0]))+" $x$, "+ p_latex + ", $r =$" +"{:.2f}".format(reg[2])+r_se_jackknife_string, va="bottom",ha="right",transform=ax.transAxes,bbox=reg_box,**fontargs)
             
         if mode=="beta" or mode=="BETA" or mode=="Beta":
             middle = sig_list_merged["EFFECT_1"].mean()
@@ -527,7 +627,7 @@ def compare_effect(path1,
     ax.set_xlabel(xylabel_prefix+label[0],**fontargs)
     ax.set_ylabel(xylabel_prefix+label[1],**fontargs)
     
-    L = ax.legend(title=legend_title,loc=legend_pos,framealpha=1,edgecolor="grey")
+    L = ax.legend(title=legend_title,loc=legend_pos,framealpha=1,edgecolor="grey",alignment="left")
     
     for i, handle in enumerate(L.legendHandles):
         handle.set_edgecolor("white")
@@ -631,7 +731,7 @@ def test_q(df,beta1,se1,beta2,se2):
     
     return df
 
-def jackknife_r2(df,x="EFFECT_1",y="EFFECT_2_aligned"):
+def jackknife_r(df,x="EFFECT_1",y="EFFECT_2_aligned"):
     """Jackknife estimation of se for rsq
 
     """
@@ -646,22 +746,22 @@ def jackknife_r2(df,x="EFFECT_1",y="EFFECT_2_aligned"):
     df_nona["nrow"] = range(n)
     
     # a list to store r2
-    r2_list=[]
+    r_list=[]
     
     # estimate r2
     for i in range(n):
         # exclude 1 record
         records_to_use = df_nona["nrow"]!=i
-        # estimate r2
+        # estimate r
         reg_jackknife = ss.linregress(df_nona.loc[records_to_use, x],df_nona.loc[records_to_use,y])
-        # add r2_i to list
-        r2_list.append(reg_jackknife[2])
+        # add r_i to list
+        r_list.append(reg_jackknife[2])
 
     # convert list to array
-    r2s = np.array(r2_list)
+    rs = np.array(r_list)
     # https://en.wikipedia.org/wiki/Jackknife_resampling
-    r2_se = np.sqrt( (n-1)/n * np.sum((r2s - np.mean(r2s))**2) )
-    return r2_se
+    r_se = np.sqrt( (n-1)/n * np.sum((rs - np.mean(rs))**2) )
+    return r_se
 
 def drop_duplicate_and_na(df,snpid="SNPID",sort_by=False,log=Log(),verbose=True):
     length_before = len(df)
